@@ -1,6 +1,6 @@
 #! /usr/bin/env python
 
-import os, sys, tempfile, shutil, hashlib, tarfile
+import os, sys, tempfile, shutil, tarfile
 import cgi, cgitb
 cgitb.enable()
 
